import React from "react";
import { Modal, Input, Form, message } from "antd";
import { SaveDataModel } from "@/api";
import { TableType } from "@/enum";

export default React.forwardRef(function AddModel(
  props: { onChange?: () => {} },
  ref
) {
  const [open, setOpen] = React.useState(false);
  const [form] = Form.useForm();
  const type = React.useRef<TableType>();
  React.useImperativeHandle(ref, () => {
    return {
      open: (tableType: TableType) => {
        type.current = tableType;
        setOpen(true);
        form.resetFields();
      },
      close: () => {
        setOpen(false);
      },
    };
  });

  const handleSubmit = () => {
    form.validateFields().then(async (values) => {
      console.log(values, message);
      await SaveDataModel({
        ...values,
        type: type.current,
      });
      message.success("创建成功");
      props.onChange?.();
      setOpen(false);
    });
  };

  return (
    <Modal
      open={open}
      width={440}
      title="创建模型"
      onCancel={() => setOpen(false)}
      onOk={handleSubmit}
    >
      <Form layout="vertical" form={form}>
        <Form.Item
          label="模型名称"
          name="name"
          rules={[
            { required: true, message: "请输入模型名称,长度50以内！", max: 50 },
          ]}
        >
          <Input placeholder="请输入模型名称" />
        </Form.Item>
        <Form.Item name="description" label="模型描述">
          <Input.TextArea placeholder="请输入模型描述" />
        </Form.Item>
      </Form>
    </Modal>
  );
});
